'''
Created by auto_sdk on 2023.12.19
'''
from seven_top.top.api.base import RestApi
class OpencrmEventreportGetRequest(RestApi):
	def __init__(self,domain='gw.api.taobao.com',port=80):
		RestApi.__init__(self,domain, port)
		self.biz_type = None
		self.end_time = None
		self.real_data = None
		self.start_time = None

	def getapiname(self):
		return 'taobao.opencrm.eventreport.get'



from seven_top.top.api.rest.OpentradeCreateOrderRequest import OpentradeCreateOrderRequest
from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyttsRequest import AlibabaAliqinTaNumberSinglecallbyttsRequest
from seven_top.top.api.rest.SkusCustomGetRequest import SkusCustomGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountReportRequest import JstSmsOfficialaccountReportRequest
from seven_top.top.api.rest.TmcMessageProduceRequest import TmcMessageProduceRequest
from seven_top.top.api.rest.ItemsCustomGetRequest import ItemsCustomGetRequest
from seven_top.top.api.rest.FuwuSaleLinkGenRequest import FuwuSaleLinkGenRequest
from seven_top.top.api.rest.AlibabaAliqinTaNumberSinglecallbyvoiceRequest import AlibabaAliqinTaNumberSinglecallbyvoiceRequest
from seven_top.top.api.rest.ItemSellerGetRequest import ItemSellerGetRequest
from seven_top.top.api.rest.KfcKeywordSearchRequest import KfcKeywordSearchRequest
from seven_top.top.api.rest.JstSmsMessageDirectBatchsendRequest import JstSmsMessageDirectBatchsendRequest
from seven_top.top.api.rest.TmcMessagesProduceRequest import TmcMessagesProduceRequest
from seven_top.top.api.rest.SubuserDepartmentsGetRequest import SubuserDepartmentsGetRequest
from seven_top.top.api.rest.RefundGetRequest import RefundGetRequest
from seven_top.top.api.rest.OpenuidGetRequest import OpenuidGetRequest
from seven_top.top.api.rest.RefundsReceiveGetRequest import RefundsReceiveGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateRequest import MiniappTemplateUpdateRequest
from seven_top.top.api.rest.ItemsOnsaleGetRequest import ItemsOnsaleGetRequest
from seven_top.top.api.rest.SellercenterSubusersGetRequest import SellercenterSubusersGetRequest
from seven_top.top.api.rest.MiniappTemplateQueryappRequest import MiniappTemplateQueryappRequest
from seven_top.top.api.rest.FuwuScoresGetRequest import FuwuScoresGetRequest
from seven_top.top.api.rest.RefundMessageAddRequest import RefundMessageAddRequest
from seven_top.top.api.rest.ItempropvaluesGetRequest import ItempropvaluesGetRequest
from seven_top.top.api.rest.MiniappTemplateOnlineappRequest import MiniappTemplateOnlineappRequest
from seven_top.top.api.rest.FilesGetRequest import FilesGetRequest
from seven_top.top.api.rest.TopAuthTokenCreateRequest import TopAuthTokenCreateRequest
from seven_top.top.api.rest.TmcMessagesConsumeRequest import TmcMessagesConsumeRequest
from seven_top.top.api.rest.MiniappShorturlCreateRequest import MiniappShorturlCreateRequest
from seven_top.top.api.rest.SellercenterRolesGetRequest import SellercenterRolesGetRequest
from seven_top.top.api.rest.VasSubscSearchRequest import VasSubscSearchRequest
from seven_top.top.api.rest.MiniappTemplateRollbackRequest import MiniappTemplateRollbackRequest
from seven_top.top.api.rest.ItemcatsGetRequest import ItemcatsGetRequest
from seven_top.top.api.rest.SellercatsListGetRequest import SellercatsListGetRequest
from seven_top.top.api.rest.AlibabaBeneiftDrawRequest import AlibabaBeneiftDrawRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumSendRequest import AlibabaAliqinTaSmsNumSendRequest
from seven_top.top.api.rest.RefundRefuseRequest import RefundRefuseRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOnlineRequest import JstSmsOfficialaccountOnlineRequest
from seven_top.top.api.rest.JstSmsOfficialaccountCancelRequest import JstSmsOfficialaccountCancelRequest
from seven_top.top.api.rest.RefundsApplyGetRequest import RefundsApplyGetRequest
from seven_top.top.api.rest.JstSmsMessageSendRequest import JstSmsMessageSendRequest
from seven_top.top.api.rest.TopIpoutGetRequest import TopIpoutGetRequest
from seven_top.top.api.rest.TmcGroupDeleteRequest import TmcGroupDeleteRequest
from seven_top.top.api.rest.ShopSellerGetRequest import ShopSellerGetRequest
from seven_top.top.api.rest.SellercenterUserPermissionsGetRequest import SellercenterUserPermissionsGetRequest
from seven_top.top.api.rest.JstSmsMessageShorturlQueryRequest import JstSmsMessageShorturlQueryRequest
from seven_top.top.api.rest.CrmMemberIdentityGetRequest import CrmMemberIdentityGetRequest
from seven_top.top.api.rest.TmcTopicGroupAddRequest import TmcTopicGroupAddRequest
from seven_top.top.api.rest.ShopcatsListGetRequest import ShopcatsListGetRequest
from seven_top.top.api.rest.TmcGroupsGetRequest import TmcGroupsGetRequest
from seven_top.top.api.rest.CrmMemberJoinurlGetRequest import CrmMemberJoinurlGetRequest
from seven_top.top.api.rest.VasOrderSearchRequest import VasOrderSearchRequest
from seven_top.top.api.rest.JstSmsStatusQueryRequest import JstSmsStatusQueryRequest
from seven_top.top.api.rest.HttpdnsGetRequest import HttpdnsGetRequest
from seven_top.top.api.rest.TmcTopicGroupDeleteRequest import TmcTopicGroupDeleteRequest
from seven_top.top.api.rest.MiniappTemplateOfflineappRequest import MiniappTemplateOfflineappRequest
from seven_top.top.api.rest.AlibabaBenefitQueryRequest import AlibabaBenefitQueryRequest
from seven_top.top.api.rest.AppipGetRequest import AppipGetRequest
from seven_top.top.api.rest.OpenTradeGetRequest import OpenTradeGetRequest
from seven_top.top.api.rest.JstSmsOaidMessageSendRequest import JstSmsOaidMessageSendRequest
from seven_top.top.api.rest.TimeGetRequest import TimeGetRequest
from seven_top.top.api.rest.TmcMessagesConfirmRequest import TmcMessagesConfirmRequest
from seven_top.top.api.rest.TopSecretGetRequest import TopSecretGetRequest
from seven_top.top.api.rest.MiniappTemplateUpdateappRequest import MiniappTemplateUpdateappRequest
from seven_top.top.api.rest.AlibabaBenefitSendRequest import AlibabaBenefitSendRequest
from seven_top.top.api.rest.ItemsSellerListGetRequest import ItemsSellerListGetRequest
from seven_top.top.api.rest.JstSmsMessageShorturlCreateRequest import JstSmsMessageShorturlCreateRequest
from seven_top.top.api.rest.SellercenterRoleAddRequest import SellercenterRoleAddRequest
from seven_top.top.api.rest.TmcUserPermitRequest import TmcUserPermitRequest
from seven_top.top.api.rest.ItempropsGetRequest import ItempropsGetRequest
from seven_top.top.api.rest.MiniappDistributionOrderItemsBindRequest import MiniappDistributionOrderItemsBindRequest
from seven_top.top.api.rest.OpenuidGetBytradeRequest import OpenuidGetBytradeRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOfflineRequest import JstSmsOfficialaccountOfflineRequest
from seven_top.top.api.rest.MiniappUserInfoGetRequest import MiniappUserInfoGetRequest
from seven_top.top.api.rest.ItemcatsAuthorizeGetRequest import ItemcatsAuthorizeGetRequest
from seven_top.top.api.rest.UserSellerGetRequest import UserSellerGetRequest
from seven_top.top.api.rest.ItemsInventoryGetRequest import ItemsInventoryGetRequest
from seven_top.top.api.rest.VasSubscribeGetRequest import VasSubscribeGetRequest
from seven_top.top.api.rest.RefundMessagesGetRequest import RefundMessagesGetRequest
from seven_top.top.api.rest.ItemSkusGetRequest import ItemSkusGetRequest
from seven_top.top.api.rest.MiniappDistributionOrderCreateRequest import MiniappDistributionOrderCreateRequest
from seven_top.top.api.rest.SubuserDutysGetRequest import SubuserDutysGetRequest
from seven_top.top.api.rest.JstSmsTaskCreateRequest import JstSmsTaskCreateRequest
from seven_top.top.api.rest.SubuserInfoUpdateRequest import SubuserInfoUpdateRequest
from seven_top.top.api.rest.TmcUserCancelRequest import TmcUserCancelRequest
from seven_top.top.api.rest.MiniappItemsGetRequest import MiniappItemsGetRequest
from seven_top.top.api.rest.AlibabaAliqinTaVoiceNumDoublecallRequest import AlibabaAliqinTaVoiceNumDoublecallRequest
from seven_top.top.api.rest.TopAuthTokenRefreshRequest import TopAuthTokenRefreshRequest
from seven_top.top.api.rest.SubuserFullinfoGetRequest import SubuserFullinfoGetRequest
from seven_top.top.api.rest.TmcGroupAddRequest import TmcGroupAddRequest
from seven_top.top.api.rest.OpenlinkSessionGetRequest import OpenlinkSessionGetRequest
from seven_top.top.api.rest.MiniapppTemplateInstantiateRequest import MiniapppTemplateInstantiateRequest
from seven_top.top.api.rest.MiniappTemplateInstantiateRequest import MiniappTemplateInstantiateRequest
from seven_top.top.api.rest.ItemSkuGetRequest import ItemSkuGetRequest
from seven_top.top.api.rest.JstSmsOfficialaccountOrderRequest import JstSmsOfficialaccountOrderRequest
from seven_top.top.api.rest.TopSecretRegisterRequest import TopSecretRegisterRequest
from seven_top.top.api.rest.JstSmsMenuinfoReportRequest import JstSmsMenuinfoReportRequest
from seven_top.top.api.rest.MiniappDistributionItemsBindRequest import MiniappDistributionItemsBindRequest
from seven_top.top.api.rest.OpenuidGetBymixnickRequest import OpenuidGetBymixnickRequest
from seven_top.top.api.rest.AlibabaAliqinTaSmsNumQueryRequest import AlibabaAliqinTaSmsNumQueryRequest
from seven_top.top.api.rest.OpenTradesSoldGetRequest import OpenTradesSoldGetRequest
from seven_top.top.api.rest.TopSdkFeedbackUploadRequest import TopSdkFeedbackUploadRequest
from seven_top.top.api.rest.SellercenterSubuserPermissionsRolesGetRequest import SellercenterSubuserPermissionsRolesGetRequest
from seven_top.top.api.rest.SubusersGetRequest import SubusersGetRequest
from seven_top.top.api.rest.TmcUserGetRequest import TmcUserGetRequest
from seven_top.top.api.rest.AlibabaBenefitDrawRequest import AlibabaBenefitDrawRequest
from seven_top.top.api.rest.JstSmsExtendcodeQueryRequest import JstSmsExtendcodeQueryRequest
from seven_top.top.api.rest.AppstoreSubscribeGetRequest import AppstoreSubscribeGetRequest
from seven_top.top.api.rest.TmcAuthGetRequest import TmcAuthGetRequest
from seven_top.top.api.rest.PromotionActivityGetRequest import PromotionActivityGetRequest
from seven_top.top.api.rest.PromotionCouponsGetRequest import PromotionCouponsGetRequest
from seven_top.top.api.rest.PromotionLimitdiscountDetailGetRequest import PromotionLimitdiscountDetailGetRequest
from seven_top.top.api.rest.PromotionLimitdiscountGetRequest import PromotionLimitdiscountGetRequest
from seven_top.top.api.rest.PromotionMealGetRequest import PromotionMealGetRequest
from seven_top.top.api.rest.MarketingPromotionKfcRequest import MarketingPromotionKfcRequest
from seven_top.top.api.rest.MiniappCloudFunctionInvokeRequest import MiniappCloudFunctionInvokeRequest
from seven_top.top.api.rest.OpentradeGroupActivtiyQueryRequest import OpentradeGroupActivtiyQueryRequest
from seven_top.top.api.rest.OpentradeGroupDetailRequest import OpentradeGroupDetailRequest
from seven_top.top.api.rest.OpentradeGroupJoinRequest import OpentradeGroupJoinRequest
from seven_top.top.api.rest.OpentradeGroupMemberInfoRequest import OpentradeGroupMemberInfoRequest
from seven_top.top.api.rest.OpentradeGroupMemberInfosRequest import OpentradeGroupMemberInfosRequest
from seven_top.top.api.rest.OpentradeGroupOpenRequest import OpentradeGroupOpenRequest
from seven_top.top.api.rest.OpentradeGroupOrderRequest import OpentradeGroupOrderRequest
from seven_top.top.api.rest.OpentradeGroupQueryRequest import OpentradeGroupQueryRequest
from seven_top.top.api.rest.OpentradeGroupSyncRequest import OpentradeGroupSyncRequest
from seven_top.top.api.rest.OpentradeSpecialItemsBindRequest import OpentradeSpecialItemsBindRequest
from seven_top.top.api.rest.OpentradeSpecialItemsQueryRequest import OpentradeSpecialItemsQueryRequest
from seven_top.top.api.rest.OpentradeSpecialItemsUnbindRequest import OpentradeSpecialItemsUnbindRequest
from seven_top.top.api.rest.OpentradeSpecialRuleUpdateRequest import OpentradeSpecialRuleUpdateRequest
from seven_top.top.api.rest.OpentradeSpecialUsersMarkRequest import OpentradeSpecialUsersMarkRequest
from seven_top.top.api.rest.OpentradeSpecialUsersQueryRequest import OpentradeSpecialUsersQueryRequest
from seven_top.top.api.rest.OpentradeToolsItemsBindRequest import OpentradeToolsItemsBindRequest
from seven_top.top.api.rest.OpentradeToolsItemsQueryRequest import OpentradeToolsItemsQueryRequest
from seven_top.top.api.rest.OpentradeToolsItemsUnbindRequest import OpentradeToolsItemsUnbindRequest
from seven_top.top.api.rest.TmallTraderateFeedsGetRequest import TmallTraderateFeedsGetRequest
from seven_top.top.api.rest.TmallTraderateItemtagsGetRequest import TmallTraderateItemtagsGetRequest
from seven_top.top.api.rest.TraderateImprImprwordsGetRequest import TraderateImprImprwordsGetRequest
from seven_top.top.api.rest.TraderatesGetRequest import TraderatesGetRequest
from seven_top.top.api.rest.MiniappCloudMongoUpdateRequest import MiniappCloudMongoUpdateRequest
from seven_top.top.api.rest.MiniappCloudMongoInsertRequest import MiniappCloudMongoInsertRequest
from seven_top.top.api.rest.OpenuidChangeRequest import OpenuidChangeRequest
from seven_top.top.api.rest.SellercenterRoleInfoGetRequest import SellercenterRoleInfoGetRequest
from seven_top.top.api.rest.SellercenterRolemembersGetRequest import SellercenterRolemembersGetRequest
from seven_top.top.api.rest.SubuserEmployeeAddRequest import SubuserEmployeeAddRequest
from seven_top.top.api.rest.JstSmsMessageBatchsendRequest import JstSmsMessageBatchsendRequest
from seven_top.top.api.rest.JstMiniappCrowdCreateRequest import JstMiniappCrowdCreateRequest
from seven_top.top.api.rest.JstMiniappCrowdMessageSendRequest import JstMiniappCrowdMessageSendRequest
from seven_top.top.api.rest.JstMiniappOpenidMessageSendRequest import JstMiniappOpenidMessageSendRequest
from seven_top.top.api.rest.MiniappAppSellerConfigCompleteRequest import MiniappAppSellerConfigCompleteRequest
from seven_top.top.api.rest.AlibabaShopCouponApplyRequest import AlibabaShopCouponApplyRequest
from seven_top.top.api.rest.AlibabaLafiteSellerActivityListRequest import AlibabaLafiteSellerActivityListRequest
from seven_top.top.api.rest.AlibabaLatourStrategyShowRequest import AlibabaLatourStrategyShowRequest
from seven_top.top.api.rest.AlibabaLafiteSellerBenefitListRequest import AlibabaLafiteSellerBenefitListRequest
from seven_top.top.api.rest.AlibabaLatourStrategyIssueRequest import AlibabaLatourStrategyIssueRequest
from seven_top.top.api.rest.CrmPointAvailableGetRequest import CrmPointAvailableGetRequest
from seven_top.top.api.rest.CrmPointAvailableGetPrivyCpRequest import CrmPointAvailableGetPrivyCpRequest
from seven_top.top.api.rest.CrmPointChangePrivyRequest import CrmPointChangePrivyRequest
from seven_top.top.api.rest.CrmPointChangeRequest import CrmPointChangeRequest
from seven_top.top.api.rest.CrmMemberIdentityGetPrivyRequest import CrmMemberIdentityGetPrivyRequest
from seven_top.top.api.rest.MiniappDistributionOrderPrecreateRequest import MiniappDistributionOrderPrecreateRequest
from seven_top.top.api.rest.MiniappDistributionOrderItemsAllBindRequest import MiniappDistributionOrderItemsAllBindRequest
from seven_top.top.api.rest.MiniappDistributionOrderGetRequest import MiniappDistributionOrderGetRequest
from seven_top.top.api.rest.MiniappDistributionMaterialUpdateRequest import MiniappDistributionMaterialUpdateRequest
from seven_top.top.api.rest.MiniappDistributionMaterialGetRequest import MiniappDistributionMaterialGetRequest
from seven_top.top.api.rest.MiniappDistributionMaterialDeleteRequest import MiniappDistributionMaterialDeleteRequest
from seven_top.top.api.rest.MiniappDistributionMaterialCreateRequest import MiniappDistributionMaterialCreateRequest
from seven_top.top.api.rest.MiniappInteractBenefitItemGetRequest import MiniappInteractBenefitItemGetRequest
from seven_top.top.api.rest.JstSmsTemplateReportRequest import JstSmsTemplateReportRequest
from seven_top.top.api.rest.JstSmsTemplateQueryRequest import JstSmsTemplateQueryRequest
from seven_top.top.api.rest.JstSmsTemplateModifyRequest import JstSmsTemplateModifyRequest
from seven_top.top.api.rest.JstSmsTemplateDeleteRequest import JstSmsTemplateDeleteRequest
from seven_top.top.api.rest.JstSmsTemplateCreateRequest import JstSmsTemplateCreateRequest
from seven_top.top.api.rest.JstSmsSignnameReportRequest import JstSmsSignnameReportRequest
from seven_top.top.api.rest.JstSmsSignnameQueryRequest import JstSmsSignnameQueryRequest
from seven_top.top.api.rest.JstSmsSignnameModifyRequest import JstSmsSignnameModifyRequest
from seven_top.top.api.rest.JstSmsSignnameDeleteRequest import JstSmsSignnameDeleteRequest
from seven_top.top.api.rest.JstSmsSignnameCreateRequest import JstSmsSignnameCreateRequest
from seven_top.top.api.rest.ChattingPlatformNewuserUserGroupListRequest import ChattingPlatformNewuserUserGroupListRequest
from seven_top.top.api.rest.ChattingPlatformNewuserUserJoinGroupInfoRequest import ChattingPlatformNewuserUserJoinGroupInfoRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstanceQueryRequest import MiniappWidgetTemplateInstanceQueryRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstanceUpdateRequest import MiniappWidgetTemplateInstanceUpdateRequest
from seven_top.top.api.rest.MiniappWidgetTemplateInstantiateRequest import MiniappWidgetTemplateInstantiateRequest
from seven_top.top.api.rest.SellercenterSubusersPageRequest import SellercenterSubusersPageRequest
from seven_top.top.api.rest.SubusersInfoQueryRequest import SubusersInfoQueryRequest
from seven_top.top.api.rest.SubusersPageRequest import SubusersPageRequest
from seven_top.top.api.rest.SubusersSubaccountSearchRequest import SubusersSubaccountSearchRequest
# CRM接口
from top.api.rest.OpencrmCrowdinstStatusGetRequest import OpencrmCrowdinstStatusGetRequest
from top.api.rest.OpencrmCrowdanalysisQueryRequest import OpencrmCrowdanalysisQueryRequest
from top.api.rest.OpencrmCtagUploadSingleCountRequest import OpencrmCtagUploadSingleCountRequest
from top.api.rest.OpencrmMexRightQueryRequest import OpencrmMexRightQueryRequest
from top.api.rest.OpencrmCrowdsSystemQueryRequest import OpencrmCrowdsSystemQueryRequest
from top.api.rest.OpencrmCrowdinstCreateRequest import OpencrmCrowdinstCreateRequest
from top.api.rest.OpencrmRuleinstanceAddRequest import OpencrmRuleinstanceAddRequest
from top.api.rest.CrmGroupAppendRequest import CrmGroupAppendRequest
from top.api.rest.CrmGradeGetRequest import CrmGradeGetRequest
from top.api.rest.OpencrmStrategyTemplateListRequest import OpencrmStrategyTemplateListRequest
from top.api.rest.OpencrmCversionCardtplQueryRequest import OpencrmCversionCardtplQueryRequest
from top.api.rest.OpencrmBenefitGradeSaveRequest import OpencrmBenefitGradeSaveRequest
from top.api.rest.OpencrmCommercialRelationQueryRequest import OpencrmCommercialRelationQueryRequest
from top.api.rest.OpencrmRuleQueryRequest import OpencrmRuleQueryRequest
from top.api.rest.OpencrmTmcsSuppliersRequest import OpencrmTmcsSuppliersRequest
from top.api.rest.OpencrmCversionTemplateUpdateRequest import OpencrmCversionTemplateUpdateRequest
from top.api.rest.OpencrmActivityCouponsQueryRequest import OpencrmActivityCouponsQueryRequest
from top.api.rest.OpencrmDatabankBrandAuthQueryRequest import OpencrmDatabankBrandAuthQueryRequest
from top.api.rest.CrmGrouptaskCheckRequest import CrmGrouptaskCheckRequest
from top.api.rest.OpencrmRuleinstanceQueryRequest import OpencrmRuleinstanceQueryRequest
from top.api.rest.OpencrmStrategyInstEventStopRequest import OpencrmStrategyInstEventStopRequest
from top.api.rest.OpencrmDigitalSmsSingleSendRequest import OpencrmDigitalSmsSingleSendRequest
from top.api.rest.OpencrmDatabankCrowdSyncRequest import OpencrmDatabankCrowdSyncRequest
from top.api.rest.CrmGradeSetRequest import CrmGradeSetRequest
from top.api.rest.OpencrmSmsSinglePostRequest import OpencrmSmsSinglePostRequest
from top.api.rest.OpencrmBenefitGradeQueryRequest import OpencrmBenefitGradeQueryRequest
from top.api.rest.OpencrmCrowdinstLiteUploadBachRequest import OpencrmCrowdinstLiteUploadBachRequest
from top.api.rest.OpencrmIsvtagGetRequest import OpencrmIsvtagGetRequest
from top.api.rest.OpencrmCtagUploadPrivyRequest import OpencrmCtagUploadPrivyRequest
from top.api.rest.OpencrmSellerBlacklistAdddeleteRequest import OpencrmSellerBlacklistAdddeleteRequest
from top.api.rest.OpencrmSmsCrowdSendRequest import OpencrmSmsCrowdSendRequest
from top.api.rest.PicturePicturesCountRequest import PicturePicturesCountRequest
from top.api.rest.OpencrmExtStrategyOperationRequest import OpencrmExtStrategyOperationRequest
from top.api.rest.OpencrmMemberSellerFetchstatusRequest import OpencrmMemberSellerFetchstatusRequest
from top.api.rest.OpencrmIsvtagUnsubscribeRequest import OpencrmIsvtagUnsubscribeRequest
from top.api.rest.TmallMeiCrmMemberSyncRequest import TmallMeiCrmMemberSyncRequest
from top.api.rest.OpencrmSignatureAdddeleteRequest import OpencrmSignatureAdddeleteRequest
from top.api.rest.OpencrmAnalysistaskCreateupdateRequest import OpencrmAnalysistaskCreateupdateRequest
from top.api.rest.CrmShopvipCancelRequest import CrmShopvipCancelRequest
from top.api.rest.CrmGroupAddRequest import CrmGroupAddRequest
from top.api.rest.FuwuPurchaseOrderConfirmRequest import FuwuPurchaseOrderConfirmRequest
from top.api.rest.OpencrmDatabankBrandsRequest import OpencrmDatabankBrandsRequest
from top.api.rest.OpencrmCrowdanalysisGetreportRequest import OpencrmCrowdanalysisGetreportRequest
from top.api.rest.TradeSimpleGetRequest import TradeSimpleGetRequest
from top.api.rest.OpencrmGradeBatchaddRequest import OpencrmGradeBatchaddRequest
from top.api.rest.OpencrmShopDecorationQueryRequest import OpencrmShopDecorationQueryRequest
from top.api.rest.CrmGroupUpdateRequest import CrmGroupUpdateRequest
from top.api.rest.OpencrmCrowdinstSaveascrowdRequest import OpencrmCrowdinstSaveascrowdRequest
from top.api.rest.OpencrmTemplateUpdateRequest import OpencrmTemplateUpdateRequest
from top.api.rest.CrmMembersGroupsBatchdeletePrivyRequest import CrmMembersGroupsBatchdeletePrivyRequest
from top.api.rest.OpencrmCardCreateupdateRequest import OpencrmCardCreateupdateRequest
from top.api.rest.OpencrmRulecfgUpdateRequest import OpencrmRulecfgUpdateRequest
from top.api.rest.OpencrmRuleCafullruleRequest import OpencrmRuleCafullruleRequest
from top.api.rest.OpencrmMemberGetOmidRequest import OpencrmMemberGetOmidRequest
from top.api.rest.PictureUserinfoGetRequest import PictureUserinfoGetRequest
from top.api.rest.PictureGetRequest import PictureGetRequest
from top.api.rest.JushitaJdpUserAddRequest import JushitaJdpUserAddRequest
from top.api.rest.TradesSimpleSoldIncrementGetRequest import TradesSimpleSoldIncrementGetRequest
from top.api.rest.OpencrmRuleinstanceStatusUpdateRequest import OpencrmRuleinstanceStatusUpdateRequest
from top.api.rest.OpencrmCouponQueryRequest import OpencrmCouponQueryRequest
from top.api.rest.OpencrmCtagUploadCrowdCreateRequest import OpencrmCtagUploadCrowdCreateRequest
from top.api.rest.OpencrmNodeFilterRequest import OpencrmNodeFilterRequest
from top.api.rest.OpencrmCrowdinstLiteUploadFinishRequest import OpencrmCrowdinstLiteUploadFinishRequest
from top.api.rest.CrmMembersIncrementGetRequest import CrmMembersIncrementGetRequest
from top.api.rest.CrmMembersGetRequest import CrmMembersGetRequest
from top.api.rest.OpencrmCardResourceGetRequest import OpencrmCardResourceGetRequest
from top.api.rest.PictureCategoryGetRequest import PictureCategoryGetRequest
from top.api.rest.OpencrmCrowdsQueryRequest import OpencrmCrowdsQueryRequest
from top.api.rest.CrmMemberOuidGetRequest import CrmMemberOuidGetRequest
from top.api.rest.OpencrmSignatureQueryPaasRequest import OpencrmSignatureQueryPaasRequest
from top.api.rest.OpencrmCommercialChargeEstimateRequest import OpencrmCommercialChargeEstimateRequest
from top.api.rest.OpencrmTemplateAdddeletePaasRequest import OpencrmTemplateAdddeletePaasRequest
from top.api.rest.OpencrmCrowdUploadBachPrivyRequest import OpencrmCrowdUploadBachPrivyRequest
from top.api.rest.OpencrmCardStrategyListQueryRequest import OpencrmCardStrategyListQueryRequest
from top.api.rest.OpencrmSystemTemplateGetRequest import OpencrmSystemTemplateGetRequest
from top.api.rest.CrmIndexEffectDataGetRequest import CrmIndexEffectDataGetRequest
from top.api.rest.OpencrmCardEstimateNumberRequest import OpencrmCardEstimateNumberRequest
from top.api.rest.CrmMemberinfoUpdateRequest import CrmMemberinfoUpdateRequest
from top.api.rest.OpencrmSmsPostRequest import OpencrmSmsPostRequest
from top.api.rest.OpencrmIsvtagSubscribeRequest import OpencrmIsvtagSubscribeRequest
from top.api.rest.FuwuSpBillreordAddRequest import FuwuSpBillreordAddRequest
from top.api.rest.OpencrmIsvtagCreateRequest import OpencrmIsvtagCreateRequest
from top.api.rest.CrmMembersGroupsBatchdeleteRequest import CrmMembersGroupsBatchdeleteRequest
from top.api.rest.OpencrmCtagUploadRequest import OpencrmCtagUploadRequest
from top.api.rest.OpencrmNodereportGetRequest import OpencrmNodereportGetRequest
from top.api.rest.OpencrmTesttmcSendRequest import OpencrmTesttmcSendRequest
from top.api.rest.OpencrmStrategyActivityListRequest import OpencrmStrategyActivityListRequest
from top.api.rest.OpencrmRuleExeruleRequest import OpencrmRuleExeruleRequest
from top.api.rest.OpencrmMemadPointdataQueryRequest import OpencrmMemadPointdataQueryRequest
from top.api.rest.OpencrmRuleAddRequest import OpencrmRuleAddRequest
from top.api.rest.OpencrmStrategyInstConfigUpdateRequest import OpencrmStrategyInstConfigUpdateRequest
from top.api.rest.CrmServiceChannelShortlinkCreateRequest import CrmServiceChannelShortlinkCreateRequest
from top.api.rest.TmallCrmMemberPointChangeRequest import TmallCrmMemberPointChangeRequest
from top.api.rest.OpencrmGradeStatusSwitchRequest import OpencrmGradeStatusSwitchRequest
from top.api.rest.OpencrmDatabankBrandAuthRequest import OpencrmDatabankBrandAuthRequest
from top.api.rest.OpencrmCardSmsSingleSendRequest import OpencrmCardSmsSingleSendRequest
from top.api.rest.CrmMembersSearchRequest import CrmMembersSearchRequest
from top.api.rest.OpencrmSignatureQueryRequest import OpencrmSignatureQueryRequest
from top.api.rest.CrmMembersSearchPrivyRequest import CrmMembersSearchPrivyRequest
from top.api.rest.OpencrmAllDomainCrowdCreateRequest import OpencrmAllDomainCrowdCreateRequest
from top.api.rest.OpencrmActionCreateupdateRequest import OpencrmActionCreateupdateRequest
from top.api.rest.OpencrmIsvtagAttrCreateupdateRequest import OpencrmIsvtagAttrCreateupdateRequest
from top.api.rest.OpencrmExtStrategyQueryRequest import OpencrmExtStrategyQueryRequest
from top.api.rest.OpencrmRuleBatchaddRequest import OpencrmRuleBatchaddRequest
from top.api.rest.OpencrmCommercialRelationOpenRequest import OpencrmCommercialRelationOpenRequest
from top.api.rest.TradesSimpleSoldGetRequest import TradesSimpleSoldGetRequest
from top.api.rest.OpencrmStrategyVipcustomergradeGetRequest import OpencrmStrategyVipcustomergradeGetRequest
from top.api.rest.OpencrmCardEffectDataYtxRequest import OpencrmCardEffectDataYtxRequest
from top.api.rest.OpencrmCtagUploadBatchCountRequest import OpencrmCtagUploadBatchCountRequest
from top.api.rest.OpencrmSmsConstInfoBuildRequest import OpencrmSmsConstInfoBuildRequest
from top.api.rest.CrmIndexEffectivieDataGetRequest import CrmIndexEffectivieDataGetRequest
from top.api.rest.OpencrmCrowdUpdateRequest import OpencrmCrowdUpdateRequest
from top.api.rest.CrmMemberGroupGetPrivyRequest import CrmMemberGroupGetPrivyRequest
from top.api.rest.CrmMembersGetPrivyRequest import CrmMembersGetPrivyRequest
from top.api.rest.OpencrmCrowdinstSplitRequest import OpencrmCrowdinstSplitRequest
from top.api.rest.AlipayXiaodaiUserPermitRequest import AlipayXiaodaiUserPermitRequest
from top.api.rest.OpencrmSmsSellerTplApplyRequest import OpencrmSmsSellerTplApplyRequest
from top.api.rest.OpencrmOrderRecordDeleteRequest import OpencrmOrderRecordDeleteRequest
from top.api.rest.OpencrmOrderRecordAddRequest import OpencrmOrderRecordAddRequest
from top.api.rest.CrmGroupsGetRequest import CrmGroupsGetRequest
from top.api.rest.OpencrmAllDomainCrowdFinishRequest import OpencrmAllDomainCrowdFinishRequest
from top.api.rest.PictureCategoryUpdateRequest import PictureCategoryUpdateRequest
from top.api.rest.OpencrmCardSmsCrowdSendRequest import OpencrmCardSmsCrowdSendRequest
from top.api.rest.OpencrmCrowdCheckRequest import OpencrmCrowdCheckRequest
from top.api.rest.TopConnectorPictureUploadRequest import TopConnectorPictureUploadRequest
from top.api.rest.CrmGroupMoveRequest import CrmGroupMoveRequest
from top.api.rest.OpencrmPointSendRequest import OpencrmPointSendRequest
from top.api.rest.PictureTokenRequest import PictureTokenRequest
from top.api.rest.OpencrmSmsSingleSendRequest import OpencrmSmsSingleSendRequest
from top.api.rest.OpencrmShortmessageSendRequest import OpencrmShortmessageSendRequest
from top.api.rest.OpencrmEventreportGetRequest import OpencrmEventreportGetRequest
from top.api.rest.OpencrmSmsUnsubscribeQueryRequest import OpencrmSmsUnsubscribeQueryRequest
from top.api.rest.PictureCategoryAddRequest import PictureCategoryAddRequest
from top.api.rest.TopConnectorEventPublishRequest import TopConnectorEventPublishRequest
from top.api.rest.OpencrmCrowdinstLiteCreateRequest import OpencrmCrowdinstLiteCreateRequest
from top.api.rest.OpencrmCrowdGetRequest import OpencrmCrowdGetRequest
from top.api.rest.OpencrmSellerBlacklistQueryRequest import OpencrmSellerBlacklistQueryRequest
from top.api.rest.OpencrmCtagUpdateRequest import OpencrmCtagUpdateRequest
from top.api.rest.OpencrmMexRightUpdateRequest import OpencrmMexRightUpdateRequest
from top.api.rest.FuwuPurchaseOrderPayRequest import FuwuPurchaseOrderPayRequest
from top.api.rest.PictureUpdateRequest import PictureUpdateRequest
from top.api.rest.OpencrmCommercialRelationCloseRequest import OpencrmCommercialRelationCloseRequest
from top.api.rest.OpencrmTagGetRequest import OpencrmTagGetRequest
from top.api.rest.OpencrmStrategyListRequest import OpencrmStrategyListRequest
from top.api.rest.TmallCrmMemberFrontUnbindPrivyRequest import TmallCrmMemberFrontUnbindPrivyRequest
from top.api.rest.OpencrmCversionCardtplUpdateRequest import OpencrmCversionCardtplUpdateRequest
from top.api.rest.TopEventPublishRequest import TopEventPublishRequest
from top.api.rest.OpencrmCrowdUploadAddRequest import OpencrmCrowdUploadAddRequest
from top.api.rest.CrmMembersGroupBatchaddPrivyRequest import CrmMembersGroupBatchaddPrivyRequest
from top.api.rest.TmallCrmMemberFrontUnbindRequest import TmallCrmMemberFrontUnbindRequest
from top.api.rest.OpencrmCrowdUploadUpdateRequest import OpencrmCrowdUploadUpdateRequest
from top.api.rest.CrmMembersIncrementGetPrivyRequest import CrmMembersIncrementGetPrivyRequest
from top.api.rest.PicturePicturesGetRequest import PicturePicturesGetRequest
from top.api.rest.OpencrmSmsCardossQueryRequest import OpencrmSmsCardossQueryRequest
from top.api.rest.TmcQueueGetRequest import TmcQueueGetRequest
from top.api.rest.OpencrmGradeUpdateRequest import OpencrmGradeUpdateRequest
from top.api.rest.OpencrmCrowdUploadFinishRequest import OpencrmCrowdUploadFinishRequest
from top.api.rest.OpencrmNodereportGetbcRequest import OpencrmNodereportGetbcRequest
from top.api.rest.TopEventSubscriptionQueryRequest import TopEventSubscriptionQueryRequest
from top.api.rest.OpencrmRuleinstanceBatchaddRequest import OpencrmRuleinstanceBatchaddRequest
from top.api.rest.OpencrmCversionDigtplCreateupdateRequest import OpencrmCversionDigtplCreateupdateRequest
from top.api.rest.JushitaJdpUsersGetRequest import JushitaJdpUsersGetRequest
from top.api.rest.OpencrmCrowdAlgorithmCheckRequest import OpencrmCrowdAlgorithmCheckRequest
from top.api.rest.OpencrmStrategyInstConfigProcessRequest import OpencrmStrategyInstConfigProcessRequest
from top.api.rest.OpencrmSmsQresultRequest import OpencrmSmsQresultRequest
from top.api.rest.OpencrmTemplateQueryRequest import OpencrmTemplateQueryRequest
from top.api.rest.OpencrmTagsQueryRequest import OpencrmTagsQueryRequest
from top.api.rest.OpencrmSmsservicestatusUpdateRequest import OpencrmSmsservicestatusUpdateRequest
from top.api.rest.OpencrmMemadLevQueryRequest import OpencrmMemadLevQueryRequest
from top.api.rest.TmcUserTopicsGetRequest import TmcUserTopicsGetRequest
from top.api.rest.TmallMeiCrmCallbackPointChangeRequest import TmallMeiCrmCallbackPointChangeRequest
from top.api.rest.OpencrmCrowdinstFilterRequest import OpencrmCrowdinstFilterRequest
from top.api.rest.OpencrmStrategyInstListRequest import OpencrmStrategyInstListRequest
from top.api.rest.OpencrmIsvtagUploadRequest import OpencrmIsvtagUploadRequest
from top.api.rest.JushitaJdpUserDeleteRequest import JushitaJdpUserDeleteRequest
from top.api.rest.OpencrmCrowdCoverageCountRequest import OpencrmCrowdCoverageCountRequest
from top.api.rest.CrmGroupDeleteRequest import CrmGroupDeleteRequest
from top.api.rest.OpencrmStrategyInstConfigGetRequest import OpencrmStrategyInstConfigGetRequest
from top.api.rest.PictureDeleteRequest import PictureDeleteRequest
from top.api.rest.CrmMembersGroupBatchaddRequest import CrmMembersGroupBatchaddRequest
from top.api.rest.OpencrmTmcsSyncRequest import OpencrmTmcsSyncRequest
from top.api.rest.OpencrmDigitalSmsCrowdSendRequest import OpencrmDigitalSmsCrowdSendRequest
from top.api.rest.CrmMemberGroupGetRequest import CrmMemberGroupGetRequest
from top.api.rest.OpenmemberSellerinfoQueryRequest import OpenmemberSellerinfoQueryRequest
from top.api.rest.TmallMeiCrmMemberSyncPrivyRequest import TmallMeiCrmMemberSyncPrivyRequest
from top.api.rest.OpencrmSmsCrowdPostRequest import OpencrmSmsCrowdPostRequest
from top.api.rest.AlibabaAliqinFcDigitalsmsCreatetemplateRequest import AlibabaAliqinFcDigitalsmsCreatetemplateRequest
from top.api.rest.OpencrmSmgStrategyQueryRequest import OpencrmSmgStrategyQueryRequest
from top.api.rest.OpencrmCrowdDeleteRequest import OpencrmCrowdDeleteRequest
from top.api.rest.OpencrmActivityCreateupdateRequest import OpencrmActivityCreateupdateRequest
from top.api.rest.OpencrmTemplateQueryPaasRequest import OpencrmTemplateQueryPaasRequest
from top.api.rest.FuwuSpConfirmApplyRequest import FuwuSpConfirmApplyRequest
from top.api.rest.OpencrmAllDomainCrowdUploadRequest import OpencrmAllDomainCrowdUploadRequest
from top.api.rest.OpencrmCrowdanalysisUpdateRequest import OpencrmCrowdanalysisUpdateRequest
from top.api.rest.OpencrmCouponquotaGetRequest import OpencrmCouponquotaGetRequest
from top.api.rest.OpencrmCrowdinstsGatherRequest import OpencrmCrowdinstsGatherRequest
from top.api.rest.OpencrmSellerOrderActivateStatusQueryRequest import OpencrmSellerOrderActivateStatusQueryRequest
from top.api.rest.OpencrmAnalysisreportGetRequest import OpencrmAnalysisreportGetRequest
from top.api.rest.OpencrmTagsCoverageCountRequest import OpencrmTagsCoverageCountRequest
from top.api.rest.OpencrmExtStrategyGenerateRequest import OpencrmExtStrategyGenerateRequest
from top.api.rest.FuwuSkuGetRequest import FuwuSkuGetRequest
from top.api.rest.OpencrmCrowdAddRequest import OpencrmCrowdAddRequest
from top.api.rest.OpencrmCtagUploadSingleCountRangeRequest import OpencrmCtagUploadSingleCountRangeRequest
from top.api.rest.PictureIsreferencedGetRequest import PictureIsreferencedGetRequest
from top.api.rest.OpencrmActivitydetailCreateupdateRequest import OpencrmActivitydetailCreateupdateRequest
from top.api.rest.OpencrmCversionTemplateQueryRequest import OpencrmCversionTemplateQueryRequest
from top.api.rest.OpencrmCversionDigtplQueryRequest import OpencrmCversionDigtplQueryRequest
from top.api.rest.CrmMemberinfoUpdatePrivyRequest import CrmMemberinfoUpdatePrivyRequest
# CRM接口